@@ -1,9 +1,7 @@
 import abc
-import io
-from typing import Type, List, Union
-
-from fastapi import UploadFile
+from typing import Type, List
 from pydantic import BaseModel
+from starlette.datastructures import UploadFile
 
 from pymultirole_plugins.schema import FormDataModel, Document
 
@@ -20,11 +18,11 @@ class ConverterBase(metaclass=abc.ABCMeta):
         pass
 
     @abc.abstractmethod
-    def convert(self, source: Union[io.IOBase, UploadFile], parameters: ConverterParameters) \
+    def convert(self, source: UploadFile, parameters: ConverterParameters) \
             -> List[Document]:
         """Parse the input source file and return a list of documents.
 
-        :param source: A file object containing the data.
+        :param source: An UploadFile containing the data.
         :param parameters: options of the converter.
         :returns: List of documents.
         """
